@@ -1,7 +1,6 @@
 use super::{Context, Module, ModuleConfig};
 use crate::configs::package::PackageConfig;
 use crate::formatter::{StringFormatter, VersionFormatter};
-use crate::utils;
 
 use ini::Ini;
 use quick_xml::events::Event as QXEvent;
@@ -44,7 +43,7 @@ pub fn module<'a>(context: &'a Context) -> Option<Module<'a>> {
 }
 
 fn get_node_package_version(context: &Context, config: &PackageConfig) -> Option<String> {
-    let file_contents = utils::read_file(&context.current_dir.join("package.json")).ok()?;
+    let file_contents = context.read_file_from_pwd("package.json")?;
     let package_json: json::Value = json::from_str(&file_contents).ok()?;
 
     if !config.display_private
@@ -68,7 +67,7 @@ fn get_node_package_version(context: &Context, config: &PackageConfig) -> Option
 }
 
 fn get_poetry_version(context: &Context, config: &PackageConfig) -> Option<String> {
-    let file_contents = utils::read_file(&context.current_dir.join("pyproject.toml")).ok()?;
+    let file_contents = context.read_file_from_pwd("pyproject.toml")?;
     let poetry_toml: toml::Value = toml::from_str(&file_contents).ok()?;
     let raw_version = poetry_toml
         .get("tool")?
@@ -80,7 +79,7 @@ fn get_poetry_version(context: &Context, config: &PackageConfig) -> Option<Strin
 }
 
 fn get_setup_cfg_version(context: &Context, config: &PackageConfig) -> Option<String> {
-    let file_contents = utils::read_file(context.current_dir.join("setup.cfg")).ok()?;
+    let file_contents = context.read_file_from_pwd("setup.cfg")?;
     let ini = Ini::load_from_str(&file_contents).ok()?;
     let raw_version = ini.get_from(Some("metadata"), "version")?;
 
@@ -92,7 +91,7 @@ fn get_setup_cfg_version(context: &Context, config: &PackageConfig) -> Option<St
 }
 
 fn get_gradle_version(context: &Context, config: &PackageConfig) -> Option<String> {
-    let file_contents = utils::read_file(context.current_dir.join("build.gradle")).ok()?;
+    let file_contents = context.read_file_from_pwd("build.gradle")?;
     let re = Regex::new(r#"(?m)^version ['"](?P<version>[^'"]+)['"]$"#).unwrap();
     let caps = re.captures(&file_contents)?;
 
@@ -100,7 +99,7 @@ fn get_gradle_version(context: &Context, config: &PackageConfig) -> Option<Strin
 }
 
 fn get_composer_version(context: &Context, config: &PackageConfig) -> Option<String> {
-    let file_contents = utils::read_file(context.current_dir.join("composer.json")).ok()?;
+    let file_contents = context.read_file_from_pwd("composer.json")?;
     let composer_json: json::Value = json::from_str(&file_contents).ok()?;
     let raw_version = composer_json.get("version")?.as_str()?;
 
@@ -108,7 +107,7 @@ fn get_composer_version(context: &Context, config: &PackageConfig) -> Option<Str
 }
 
 fn get_julia_project_version(context: &Context, config: &PackageConfig) -> Option<String> {
-    let file_contents = utils::read_file(context.current_dir.join("Project.toml")).ok()?;
+    let file_contents = context.read_file_from_pwd("Project.toml")?;
     let project_toml: toml::Value = toml::from_str(&file_contents).ok()?;
     let raw_version = project_toml.get("version")?.as_str()?;
 
@@ -116,7 +115,7 @@ fn get_julia_project_version(context: &Context, config: &PackageConfig) -> Optio
 }
 
 fn get_helm_package_version(context: &Context, config: &PackageConfig) -> Option<String> {
-    let file_contents = utils::read_file(context.current_dir.join("Chart.yaml")).ok()?;
+    let file_contents = context.read_file_from_pwd("Chart.yaml")?;
     let yaml = yaml_rust::YamlLoader::load_from_str(&file_contents).ok()?;
     let version = yaml.first()?["version"].as_str()?;
 
@@ -124,7 +123,7 @@ fn get_helm_package_version(context: &Context, config: &PackageConfig) -> Option
 }
 
 fn get_mix_version(context: &Context, config: &PackageConfig) -> Option<String> {
-    let file_contents = utils::read_file(context.current_dir.join("mix.exs")).ok()?;
+    let file_contents = context.read_file_from_pwd("mix.exs")?;
     let re = Regex::new(r#"(?m)version: "(?P<version>[^"]+)""#).unwrap();
     let caps = re.captures(&file_contents)?;
 
@@ -132,8 +131,8 @@ fn get_mix_version(context: &Context, config: &PackageConfig) -> Option<String>
 }
 
 fn get_maven_version(context: &Context, config: &PackageConfig) -> Option<String> {
-    let pom_file = utils::read_file(context.current_dir.join("pom.xml")).ok()?;
-    let mut reader = QXReader::from_str(&pom_file);
+    let file_contents = context.read_file_from_pwd("pom.xml")?;
+    let mut reader = QXReader::from_str(&file_contents);
     reader.trim_text(true);
 
     let mut buf = vec![];
@@ -171,8 +170,8 @@ fn get_maven_version(context: &Context, config: &PackageConfig) -> Option<String
 }
 
 fn get_meson_version(context: &Context, config: &PackageConfig) -> Option<String> {
-    let file_contents = utils::read_file(context.current_dir.join("meson.build"))
-        .ok()?
+    let file_contents = context
+        .read_file_from_pwd("meson.build")?
         .split_ascii_whitespace()
         .collect::<String>();
 
@@ -183,14 +182,14 @@ fn get_meson_version(context: &Context, config: &PackageConfig) -> Option<String
 }
 
 fn get_vmod_version(context: &Context, config: &PackageConfig) -> Option<String> {
-    let file_contents = utils::read_file(context.current_dir.join("v.mod")).ok()?;
+    let file_contents = context.read_file_from_pwd("v.mod")?;
     let re = Regex::new(r"(?m)^\s*version\s*:\s*'(?P<version>[^']+)'").unwrap();
     let caps = re.captures(&file_contents)?;
     format_version(&caps["version"], config.version_format)
 }
 
 fn get_vpkg_version(context: &Context, config: &PackageConfig) -> Option<String> {
-    let file_contents = utils::read_file(context.current_dir.join("vpkg.json")).ok()?;
+    let file_contents = context.read_file_from_pwd("vpkg.json")?;
     let vpkg_json: json::Value = json::from_str(&file_contents).ok()?;
     let raw_version = vpkg_json.get("version")?.as_str()?;
 
@@ -198,14 +197,14 @@ fn get_vpkg_version(context: &Context, config: &PackageConfig) -> Option<String>
 }
 
 fn get_sbt_version(context: &Context, config: &PackageConfig) -> Option<String> {
-    let file_contents = utils::read_file(context.current_dir.join("build.sbt")).ok()?;
+    let file_contents = context.read_file_from_pwd("build.sbt")?;
     let re = Regex::new(r"(?m)^(.*/)*\s*version\s*:=\s*.(?P<version>[\d\.]+)").unwrap();
     let caps = re.captures(&file_contents)?;
     format_version(&caps["version"], config.version_format)
 }
 
 fn get_cargo_version(context: &Context, config: &PackageConfig) -> Option<String> {
-    let file_contents = utils::read_file(&context.current_dir.join("Cargo.toml")).ok()?;
+    let file_contents = context.read_file_from_pwd("Cargo.toml")?;
 
     let cargo_toml: toml::Value = toml::from_str(&file_contents).ok()?;
     let raw_version = cargo_toml.get("package")?.get("version")?.as_str()?;
@@ -231,7 +230,7 @@ fn get_nimble_version(context: &Context, config: &PackageConfig) -> Option<Strin
 }
 
 fn get_shard_version(context: &Context, config: &PackageConfig) -> Option<String> {
-    let file_contents = utils::read_file(&context.current_dir.join("shard.yml")).ok()?;
+    let file_contents = context.read_file_from_pwd("shard.yml")?;
 
     let data = yaml_rust::YamlLoader::load_from_str(&file_contents).ok()?;
     let raw_version = data.first()?["version"].as_str()?;
@@ -240,7 +239,7 @@ fn get_shard_version(context: &Context, config: &PackageConfig) -> Option<String
 }
 
 fn get_dart_pub_version(context: &Context, config: &PackageConfig) -> Option<String> {
-    let file_contents = utils::read_file(&context.current_dir.join("pubspec.yaml")).ok()?;
+    let file_contents = context.read_file_from_pwd("pubspec.yaml")?;
 
     let data = yaml_rust::YamlLoader::load_from_str(&file_contents).ok()?;
     let raw_version = data.first()?["version"].as_str()?;
