@@ -188,6 +188,21 @@ pub fn fixture_repo(provider: FixtureProvider) -> io::Result<TempDir> {
                 .current_dir(&path.path())
                 .output()?;
 
+            // Prevent intermittent test failures and ensure that the result of git commands
+            // are available during I/O-contentious tests, by having git run `fsync`.
+            // This is especially important on Windows.
+            // Newer, more far-reaching git setting for `fsync`, that's not yet widely supported:
+            create_command("git")?
+                .args(&["config", "--local", "core.fsync", "all"])
+                .current_dir(&path.path())
+                .output()?;
+
+            // Older git setting for `fsync` for compatibility with older git versions:
+            create_command("git")?
+                .args(&["config", "--local", "core.fsyncObjectFiles", "true"])
+                .current_dir(&path.path())
+                .output()?;
+
             create_command("git")?
                 .args(&["reset", "--hard", "HEAD"])
                 .current_dir(&path.path())
